# RASA Codeless 0.0.1a1 Release

### RASA Codeless provides a GUI for NLU pipeline configurations and model training and evaluation for Rasa Conversational AIs.

## Features
- Allows configuring, training, and evaluating RASA models efficiently through a React based UI
- Fully supports rasa 2.8.x projects
- Provides an easy-to-use CLI
- Provides an efficient server-based GUI
- Requires minimum machine learning expertise and RASA framework specific knowledge

## What's Cooking?
- Generating loss curves for model evaluation
- Training data management
- Learning curve insights

## Limitations and Known Issues
- Does not support early stopping
- Training ETA not available
- Evaluations are limited to DIET Classifier

📒 Docs: https://rasa-codeless.github.io 
📦 PyPi: https://pypi.org/project/rasac/0.0.1a1/ 
🪵 Full Changelog: Refer the relevant GitHub branch (v0.0.1a1)

